Module input

Module input 

Structs

Input
Warning InputOwned and Input are an unstable API. This could change at any time without notice. Please consider using primitives like any over functions in this struct. Please. If you do, support is not guaranteed. Changing the offset to arbitrary values could lead to undefined behavior. Don’t modify anything in this struct if you want to be free of UB and/or segfaults.
InputOwned
Marker

Traits

InputType
SliceInput
Implemented by inputs that represent slice-like streams of input tokens.
StrInput